@@ -14,7 +14,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from pynetbox.core.response import Record, JsonField
+from pynetbox.core.response import JsonField, Record
 
 
 class ConfigContexts(Record):
